(window.webpackJsonp=window.webpackJsonp||[]).push([[23],{251:function(a,n){a.exports=function(){return{title:"Kod",blocks:"Blok",linkTooltip:"Simpan dan pautkan kepada blok.",runTooltip:"Jalankan aturcara yang ditetapkan oleh blok-blok di dalam ruang kerja.",badCode:"Ralat aturcara:\n%1",timeout:"Takat maksimum lelaran pelaksanaan dicecah.",trashTooltip:"Buang semua Blok.",catLogic:"Logik",catLoops:"Gelung",catMath:"Matematik",catText:"Teks",catLists:"Senarai",catColour:"Warna",catVariables:"Pemboleh ubah",catFunctions:"Fungsi",listVariable:"senarai",textVariable:"teks",httpRequestError:"Permintaan itu terdapat masalah.",linkAlert:"Kongsikan blok-blok anda dengan pautan ini:\n\n%1",hashError:"Maaf, '%1' tidak berpadanan dengan sebarang aturcara yang disimpan.",xmlError:"Fail simpanan anda tidak dapat dimuatkan. Jangan-jangan ia dicipta dengan versi Blockly yang berlainan?",badXml:"Ralat ketika menghuraikan XML:\n%1\n\nPilih 'OK' untuk melucutkan suntingan anda atau 'Batal' untuk bersambung menyunting XML-nya."}}}}]);
//# sourceMappingURL=23.js.map