(window.webpackJsonp=window.webpackJsonp||[]).push([[11],{239:function(t,o){t.exports=function(){return{title:"کد",blocks:"بلوک‌ها",linkTooltip:"ذخیره و پیوند به بلوک‌ها.",runTooltip:"اجرای برنامهٔ تعریف‌شده توسط بلوک‌ها در فضای کار.",badCode:"خطای برنامه:\n%1",timeout:"حداکثر تکرارهای اجرا رد شده‌است.",trashTooltip:"دورریختن همهٔ بلوک‌ها.",catLogic:"منطق",catLoops:"حلقه‌ها",catMath:"ریاضی",catText:"متن",catLists:"فهرست‌ها",catColour:"رنگ",catVariables:"متغییرها",catFunctions:"توابع",listVariable:"فهرست",textVariable:"متن",httpRequestError:"مشکلی با درخواست وجود داشت.",linkAlert:"اشتراک‌گذاری بلاک‌هایتان با این پیوند:\n\n%1",hashError:"شرمنده، «%1» با هیچ برنامهٔ ذخیره‌شده‌ای تطبیق پیدا نکرد.",xmlError:"نتوانست پروندهٔ ذخیرهٔ شما بارگیری شود.  احتمالاً با نسخهٔ متفاوتی از بلوکی درست شده‌است؟",badXml:"خطای تجزیهٔ اکس‌ام‌ال:\n%1\n\n«باشد» را برای ذخیره و «فسخ» را برای ویرایش بیشتر اکس‌ام‌ال انتخاب کنید."}}}}]);
//# sourceMappingURL=11.js.map