(window.webpackJsonp=window.webpackJsonp||[]).push([[38],{266:function(o,a){o.exports=function(){return{title:"ngoq",blocks:"ngoghmey",linkTooltip:"",runTooltip:"",badCode:"Qagh:\n%1",timeout:"tlhoy nI'qu' poH.",trashTooltip:"",catLogic:"meq",catLoops:"vIHtaHbogh ghomey",catMath:"mI'QeD",catText:"ghItlhHommey",catLists:"tetlhmey",catColour:"rItlh",catVariables:"lIwmey",catFunctions:"mIwmey",listVariable:"tetlh",textVariable:"ghItlhHom",httpRequestError:"Qapbe' tlhobmeH QIn.",linkAlert:"latlhvaD ngoghmeylIj DangeHmeH Quvvam yIlo':\n\n%1",hashError:"Do'Ha', ngogh nab pollu'pu'bogh 'oHbe'law' \"%1\"'e'.",xmlError:"ngogh nablIj pollu'pu'bogh chu'qa'laHbe' vay'.  chaq pollu'pu'DI' ghunmeH ngogh pIm lo'lu'pu'.",badXml:"XML yajchu'laHbe' vay':\n%1\n\nchoHmeylIj DalonmeH \"ruch\" yIwIv pagh XML DachoHqa'meH \"qIl\" yIwIv."}}}}]);
//# sourceMappingURL=38.js.map