(window.webpackJsonp=window.webpackJsonp||[]).push([[27],{255:function(o,a){o.exports=function(){return{title:"Kod",blocks:"Bloki",linkTooltip:"Zapisz i podlinkuj do bloków",runTooltip:"Uruchom program zdefinowany przez bloki w obszarze roboczym",badCode:"Błąd programu:\n%1",timeout:"Maksymalna liczba iteracji wykonywań przekroczona",trashTooltip:"Odrzuć wszystkie bloki.",catLogic:"Logika",catLoops:"Pętle",catMath:"Matematyka",catText:"Tekst",catLists:"Listy",catColour:"Kolor",catVariables:"Zmienne",catFunctions:"Funkcje",listVariable:"lista",textVariable:"tekst",httpRequestError:"Wystąpił problem z żądaniem.",linkAlert:"Udpostępnij swoje bloki korzystając z poniższego linku : \n\n\n%1",hashError:'Przepraszamy, "%1" nie odpowiada żadnemu zapisanemu programowi.',xmlError:"Nie można załadować zapisanego pliku. Być może został utworzony za pomocą innej wersji Blockly?",badXml:"Błąd parsowania XML : \n%1\n\nZaznacz 'OK' aby odrzucić twoje zmiany lub 'Cancel', żeby w przyszłości edytować XML."}}}}]);
//# sourceMappingURL=27.js.map