(window.webpackJsonp=window.webpackJsonp||[]).push([[25],{253:function(e,n){e.exports=function(){return{title:"Code",blocks:"Blokken",linkTooltip:"Opslaan en koppelen naar blokken.",runTooltip:"Voer het programma uit dat met de blokken in de werkruimte is gemaakt.",badCode:"Programmafout:\n%1",timeout:"Het maximale aantal iteraties is overschreden.",trashTooltip:"Alle blokken verwijderen",catLogic:"Logica",catLoops:"Lussen",catMath:"Formules",catText:"Tekst",catLists:"Lijsten",catColour:"Kleur",catVariables:"Variabelen",catFunctions:"Functies",listVariable:"lijst",textVariable:"tekst",httpRequestError:"Er is een probleem opgetreden tijdens het verwerken van het verzoek.",linkAlert:"Deel uw blokken via deze koppeling:\n\n%1",hashError:'"%1" komt helaas niet overeen met een opgeslagen bestand.',xmlError:"Uw opgeslagen bestand kan niet geladen worden. Is het misschien gemaakt met een andere versie van Blockly?",badXml:'Fout tijdens het verwerken van de XML:\n%1\n\nSelecteer "OK" om uw wijzigingen te negeren of "Annuleren" om de XML verder te bewerken.'}}}}]);
//# sourceMappingURL=25.js.map