(window.webpackJsonp=window.webpackJsonp||[]).push([[9],{237:function(o,a){o.exports=function(){return{title:"Código",blocks:"Bloques",linkTooltip:"Guarda conexión a los bloques.",runTooltip:"Ejecute el programa definido por los bloques en el área de trabajo.",badCode:"Error del programa:\n%1",timeout:"Se excedio el máximo de iteraciones ejecutadas permitidas.",trashTooltip:"Descartar todos los bloques.",catLogic:"Lógica",catLoops:"Secuencias",catMath:"Matemáticas",catText:"Texto",catLists:"Listas",catColour:"Color",catVariables:"Variables",catFunctions:"Funciones",listVariable:"lista",textVariable:"texto",httpRequestError:"Hubo un problema con la petición.",linkAlert:"Comparte tus bloques con este enlace:\n\n%1",hashError:"«%1» no corresponde con ningún programa guardado.",xmlError:"No se pudo cargar el archivo guardado.  ¿Quizá fue creado con otra versión de Blockly?",badXml:"Error de análisis XML:\n%1\n\nSelecciona OK para abandonar tus cambios o Cancelar para seguir editando el XML."}}}}]);
//# sourceMappingURL=9.js.map