(window.webpackJsonp=window.webpackJsonp||[]).push([[10],{238:function(a,t){a.exports=function(){return{title:"Kood",blocks:"Plokid",linkTooltip:"Salvesta ja tekita link plokkidele.",runTooltip:"Käivita töölaual olevate plokkidega defineeritud programm.",badCode:"Viga programmis:\n%1",timeout:"Käivitatavate iteratsioonide maksimaalne arv on ületatud.",trashTooltip:"Eemalda kõik plokid.",catLogic:"Loogika",catLoops:"Kordus",catMath:"Matemaatika",catText:"Tekst",catLists:"Loendid",catColour:"Värv",catVariables:"Muutujad",catFunctions:"Funktsioonid",listVariable:"loend",textVariable:"tekst",httpRequestError:"Probleem päringuga.",linkAlert:"Oma plokke saad jagada selle lingiga:\n\n%1",hashError:"Vabandust, kuid '%1' ei vasta ühelegi salvestatud programmile.",xmlError:"Su salvestatud faili ei õnnestunud laadida. Võibolla on see loodud mõne teise Blockly versiooniga?",badXml:"Viga XML-i parsimisel:\n%1\n\nTehtud muudatustest loobumiseks vajuta 'OK', XML-i muudatuste tegemise jätkamiseks 'Katkesta'."}}}}]);
//# sourceMappingURL=10.js.map