(window.webpackJsonp=window.webpackJsonp||[]).push([[0],{228:function(t,o){t.exports=function(){return{title:"كود",blocks:"البلوكات",linkTooltip:"احفظ ووصلة إلى البلوكات.",runTooltip:"شغل البرنامج المعرف بواسطة البلوكات في مساحة العمل.",badCode:"خطأ في البرنامج:\n %1",timeout:"تم تجاوز الحد الأقصى لتكرارات التنفيذ .",trashTooltip:"تجاهل كل البلوكات.",catLogic:"منطق",catLoops:"الحلقات",catMath:"رياضيات",catText:"نص",catLists:"قوائم",catColour:"لون",catVariables:"متغيرات",catFunctions:"إجراءات",listVariable:"قائمة",textVariable:"نص",httpRequestError:"كانت هناك مشكلة مع هذا الطلب.",linkAlert:"مشاركة كود بلوكلي الخاص بك مع هذا الرابط:\n %1",hashError:"عذراً،ال '%1' لا تتوافق مع أي برنامج تم حفظه.",xmlError:"تعذر تحميل الملف المحفوظة الخاصة بك.  ربما تم إنشاؤه باستخدام إصدار مختلف من بلوكلي؟",badXml:"خطأ في توزيع ال \"XML\":\n %1\n\nحدد 'موافق' للتخلي عن التغييرات أو 'إلغاء الأمر' لمواصلة تحرير ال\"XML\"."}}}}]);
//# sourceMappingURL=0.js.map