(window.webpackJsonp=window.webpackJsonp||[]).push([[34],{262:function(t,o){t.exports=function(){return{title:"Кôд",blocks:"Блокови",linkTooltip:"Сачувајте и повежите са блоковима.",runTooltip:"Покрените програм заснован на блоковима у радном простору.",badCode:"Грешка у програму:\n%1",timeout:"Достигнут је максималан број понављања у извршавању.",trashTooltip:"Одбаците све блокове.",catLogic:"Логика",catLoops:"Петље",catMath:"Математика",catText:"Текст",catLists:"Спискови",catColour:"Боја",catVariables:"Променљиве",catFunctions:"Процедуре",listVariable:"списак",textVariable:"текст",httpRequestError:"Дошло је до проблема у захтеву.",linkAlert:"Делите своје блокове овом везом:\n\n%1",hashError:"„%1“ не одговара ниједном сачуваном програму.",xmlError:"Не могу да учитам сачувану датотеку. Можда је направљена другом верзијом Blockly-ја.",badXml:"Грешка при рашчлањивању XML-а:\n%1\n\nПритисните „У реду“ да напустите измене или „Откажи“ да наставите са уређивањем XML датотеке."}}}}]);
//# sourceMappingURL=34.js.map