(window.webpackJsonp=window.webpackJsonp||[]).push([[24],{252:function(e,r){e.exports=function(){return{title:"Kode",blocks:"Blokker",linkTooltip:"Lagre og lenke til blokker.",runTooltip:"Kjør programmet definert av blokken i arbeidsområdet.",badCode:"Programfeil:\n%1",timeout:"Det maksimale antallet utførte looper er oversteget.",trashTooltip:"Fjern alle blokker",catLogic:"Logikk",catLoops:"Looper",catMath:"Matte",catText:"Tekst",catLists:"Lister",catColour:"Farge",catVariables:"Variabler",catFunctions:"Funksjoner",listVariable:"Liste",textVariable:"Tekst",httpRequestError:"Det oppsto et problem med forespørselen din",linkAlert:"Del dine blokker med denne lenken:\n\n%1",hashError:"Beklager, '%1' samsvarer ikke med noe lagret program.",xmlError:"Kunne ikke laste inn filen. Kanskje den ble laget med en annen versjon av Blockly?",badXml:"Feil ved parsering av XML:\n%1\n\nVelg 'OK' for å avbryte endringene eller 'Cancel' for å fortsette å redigere XML-koden."}}}}]);
//# sourceMappingURL=24.js.map