(window.webpackJsonp=window.webpackJsonp||[]).push([[21],{249:function(t,o){t.exports=function(){return{title:"코드",blocks:"블록",linkTooltip:"블록을 저장하고 링크를 가져옵니다.",runTooltip:"작업 공간에서 블록으로 정의된 프로그램을 실행합니다.",badCode:"프로그램 오류:\n%1",timeout:"최대 실행 반복을 초과했습니다.",trashTooltip:"모든 블록을 버립니다.",catLogic:"논리",catLoops:"반복",catMath:"수학",catText:"텍스트",catLists:"목록",catColour:"색",catVariables:"변수",catFunctions:"기능",listVariable:"목록",textVariable:"텍스트",httpRequestError:"요청에 문제가 있습니다.",linkAlert:"다음 링크로 블록을 공유하세요:\n\n%1",hashError:"죄송하지만 '%1'은 어떤 저장된 프로그램으로 일치하지 않습니다.",xmlError:"저장된 파일을 불러올 수 없습니다. 혹시 블록리의 다른 버전으로 만들었습니까?",badXml:"XML 구문 분석 오류:\n%1\n\n바뀜을 포기하려면 '확인'을 선택하고 XML을 더 편집하려면 '취소'를 선택하세요."}}}}]);
//# sourceMappingURL=21.js.map