(window.webpackJsonp=window.webpackJsonp||[]).push([[42],{270:function(t,o){t.exports=function(){return{title:"代码",blocks:"块",linkTooltip:"保存模块并生成链接。",runTooltip:"于工作区中运行块所定义的程式。",badCode:"程序错误：\n%1",timeout:"超过最大执行行数。",trashTooltip:"放弃所有块。",catLogic:"逻辑",catLoops:"循环",catMath:"数学",catText:"文本",catLists:"列表",catColour:"颜色",catVariables:"变量",catFunctions:"函数",listVariable:"列表",textVariable:"文本",httpRequestError:"请求存在问题。",linkAlert:"通过这个链接分享您的模块：\n\n%1",hashError:"对不起，没有任何已保存的程序对应'%1' 。",xmlError:"无法载入您保存的文件。您是否使用其他版本的Blockly创建该文件的？",badXml:"XML解析错误：\n%1\n\n选择“确定”以取消您对XML的修改，或选择“取消”以继续编辑XML。"}}}}]);
//# sourceMappingURL=42.js.map