(window.webpackJsonp=window.webpackJsonp||[]).push([[13],{241:function(t,o){t.exports=function(){return{title:"קוד",blocks:"קטעי קוד",linkTooltip:"שמירה וקישור לקטעי קוד.",runTooltip:"הרצת התכנית שהוגדרה על ידי קטעי הקוד שבמרחב העבודה.",badCode:"שגיאה בתכנית: %1",timeout:"חריגה ממספר פעולות חוזרות אפשריות.",trashTooltip:"השלך את כל קטעי הקוד.",catLogic:"לוגיקה",catLoops:"לולאות",catMath:"מתמטיקה",catText:"טקסט",catLists:"רשימות",catColour:"צבע",catVariables:"משתנים",catFunctions:"פונקציות",listVariable:"רשימה",textVariable:"טקסט",httpRequestError:"הבקשה נכשלה.",linkAlert:"ניתן לשתף את קטעי הקוד שלך באמצעות קישור זה:\n\n%1",hashError:"לצערנו, '%1' איננו מתאים לאף אחת מהתוכניות השמורות",xmlError:"נסיון הטעינה של הקובץ השמור שלך נכשל. האם ייתכן שהוא נוצר בגרסא שונה של בלוקלי?",badXml:"תקלה בפענוח XML:\n\n%1\n\nנא לבחור 'אישור' כדי לנטוש את השינויים שלך או 'ביטול' כדי להמשיך ולערוך את ה־XML."}}}}]);
//# sourceMappingURL=13.js.map