(window.webpackJsonp=window.webpackJsonp||[]).push([[7],{235:function(t,o){t.exports=function(){return{title:"Κώδικας",blocks:"Μπλοκ",linkTooltip:"Αποθηκεύει και συνδέει σε μπλοκ.",runTooltip:"Εκτελεί το πρόγραμμα που ορίζεται από τα μπλοκ στον χώρο εργασίας.",badCode:"Σφάλμα προγράμματος:\n%1",timeout:"Υπέρβαση μέγιστου αριθμού επαναλήψεων.",trashTooltip:"Απόρριψη όλων των μπλοκ.",catLogic:"Λογική",catLoops:"Επαναλήψεις",catMath:"Μαθηματικά",catText:"Κείμενο",catLists:"Λίστες",catColour:"Χρώμα",catVariables:"Μεταβλητές",catFunctions:"Συναρτήσεις",listVariable:"λίστα",textVariable:"κείμενο",httpRequestError:"Υπήρξε πρόβλημα με το αίτημα.",linkAlert:"Κοινοποίησε τα μπλοκ σου με αυτόν τον σύνδεσμο:\n\n%1",hashError:"Λυπάμαι, το «%1» δεν αντιστοιχεί σε κανένα αποθηκευμένο πρόγραμμα.",xmlError:"Δεν μπορώ να φορτώσω το αποθηκευμένο αρχείο σου.  Μήπως δημιουργήθηκε από μία παλιότερη έκδοση του Blockly;",badXml:"Σφάλμα ανάλυσης XML:\n%1\n\nΕπίλεξε «Εντάξει» για να εγκαταλείψεις τις αλλαγές σου ή «Ακύρωση» για να επεξεργαστείς το XML κι άλλο."}}}}]);
//# sourceMappingURL=7.js.map