(window.webpackJsonp=window.webpackJsonp||[]).push([[30],{258:function(e,a){e.exports=function(){return{title:"Cod",blocks:"Blocuri",linkTooltip:"Salvează și adaugă la blocuri.",runTooltip:"Execută programul definit de către blocuri în spațiul de lucru.",badCode:"Eroare de program:\n%1",timeout:"Numărul maxim de iterații a fost depășit.",trashTooltip:"Șterge toate blocurile.",catLogic:"Logic",catLoops:"Bucle",catMath:"Matematică",catText:"Text",catLists:"Liste",catColour:"Culoare",catVariables:"Variabile",catFunctions:"Funcții",listVariable:"listă",textVariable:"text",httpRequestError:"A apărut o problemă la solicitare.",linkAlert:"Distribuie-ți blocurile folosind această legătură:\n\n%1",hashError:"Scuze, „%1” nu corespunde nici unui program salvat.",xmlError:"Sistemul nu a putut încărca fișierul salvat. Poate că a fost creat cu o altă versiune de Blockly?",badXml:"Eroare de parsare XML:\n%1\n\nAlege „OK” pentru a renunța la modificările efectuate sau „Revocare” pentru a modifica în continuare fișierul XML."}}}}]);
//# sourceMappingURL=30.js.map