(window.webpackJsonp=window.webpackJsonp||[]).push([[39],{267:function(a,e){a.exports=function(){return{title:"Kod",blocks:"Bloklar",linkTooltip:"Blokları ve bağlantı adresini kaydet.",runTooltip:"Çalışma alanında bloklar tarafından tanımlanan programını çalıştırın.",badCode:"Program hatası:\n %1",timeout:"Maksimum yürütme yinelemeleri aşıldı.",trashTooltip:"Bütün blokları at.",catLogic:"Mantık",catLoops:"Döngüler",catMath:"Matematik",catText:"Metin",catLists:"Listeler",catColour:"Renk",catVariables:"Değişkenler",catFunctions:"İşlevler",listVariable:"liste",textVariable:"metin",httpRequestError:"İstek ile ilgili bir problem var.",linkAlert:"Bloklarını bu bağlantı ile paylaş:\n\n%1",hashError:"Üzgünüz, '%1' hiç bir kaydedilmiş program ile uyuşmuyor.",xmlError:"Kaydedilen dosyanız yüklenemiyor\nBlockly'nin önceki sürümü ile kaydedilmiş olabilir mi?",badXml:"XML ayrıştırma hatası:\n%1\n\nDeğişikliklerden vazgeçmek için 'Tamam'ı, düzenlemeye devam etmek için 'İptal' seçeneğini seçiniz."}}}}]);
//# sourceMappingURL=39.js.map