(window.webpackJsonp=window.webpackJsonp||[]).push([[35],{263:function(a,t){a.exports=function(){return{title:"Kod",blocks:"Block",linkTooltip:"Spara och länka till block.",runTooltip:"Kör programmet som definierats av blocken i arbetsytan.",badCode:"Programfel:\n%1",timeout:"Det maximala antalet utförda loopar har överskridits.",trashTooltip:"Släng alla block.",catLogic:"Logik",catLoops:"Loopar",catMath:"Matematik",catText:"Text",catLists:"Listor",catColour:"Färg",catVariables:"Variabler",catFunctions:"Funktioner",listVariable:"lista",textVariable:"text",httpRequestError:"Det uppstod ett problem med begäran.",linkAlert:"Dela dina block med denna länk: \n\n%1",hashError:"Tyvärr, '%1' överensstämmer inte med något sparat program.",xmlError:"Kunde inte läsa din sparade fil. Den skapades kanske med en annan version av Blockly?",badXml:"Fel vid parsning av XML:\n%1\n\nKlicka på 'OK' för att strunta i dina ändringar eller 'Avbryt' för att fortsätta redigera XML-koden."}}}}]);
//# sourceMappingURL=35.js.map