(window.webpackJsonp=window.webpackJsonp||[]).push([[19],{247:function(t,o){t.exports=function(){return{title:"コード",blocks:"ブロック",linkTooltip:"ブロックの状態を保存してリンクを取得します。",runTooltip:"ブロックで作成したプログラムを実行します。",badCode:"プログラムのエラー:\n%1",timeout:"命令の実行回数が制限値を超えました。",trashTooltip:"すべてのブロックを消します。",catLogic:"論理",catLoops:"繰り返し",catMath:"数学",catText:"テキスト",catLists:"リスト",catColour:"色",catVariables:"変数",catFunctions:"関数",listVariable:"リスト",textVariable:"テキスト",httpRequestError:"ネットワーク接続のエラーです。",linkAlert:"ブロックの状態をこのリンクで共有できます:\n\n%1",hashError:"すみません。「%1」という名前のプログラムは保存されていません。",xmlError:"保存されたファイルを読み込めませんでした。別のバージョンのブロックリーで作成された可能性があります。",badXml:"XML のエラーです:\n%1\n\nXML の変更をやめるには「OK」、編集を続けるには「キャンセル」を選んでください。"}}}}]);
//# sourceMappingURL=19.js.map