(window.webpackJsonp=window.webpackJsonp||[]).push([[40],{268:function(t,o){t.exports=function(){return{title:"Код",blocks:"Блоки",linkTooltip:"Зберегти і пов'язати з блоками.",runTooltip:"Запустіть програму, визначену блоками у робочій області.",badCode:"Помилка програми:\n%1",timeout:"Максимальне виконання ітерацій перевищено.",trashTooltip:"Відкинути всі блоки.",catLogic:"Логіка",catLoops:"Петлі",catMath:"Математика",catText:"Текст",catLists:"Списки",catColour:"Колір",catVariables:"Змінні",catFunctions:"Функції",listVariable:"список",textVariable:"текст",httpRequestError:"Виникла проблема із запитом.",linkAlert:"Поділитися вашим блоками через посилання:\n\n%1",hashError:'На жаль, "%1" не відповідає жодній збереженій програмі.',xmlError:"Не вдалося завантажити ваш збережений файл.  Можливо, він був створений з іншої версії Blockly?",badXml:"Помилка синтаксичного аналізу XML:\n%1\n\nВиберіть \"Гаразд\", щоб відмовитися від змін або 'Скасувати' для подальшого редагування XML."}}}}]);
//# sourceMappingURL=40.js.map