(window.webpackJsonp=window.webpackJsonp||[]).push([[36],{264:function(t,o){t.exports=function(){return{title:"கணினி நிரல்",blocks:"நிரல் துண்டு",linkTooltip:"சேமித்து நிரல் துண்டிற்கு இணைக்க",runTooltip:"பணிமனை நினைவகத்தில் இயக்குக",badCode:"கணினி நிரல் கோளாறு:\n%1",timeout:"அதிகபட்ச அடுக்கின் அளவை மீரியது",trashTooltip:"நீக்கு",catLogic:"தர்க வகை",catLoops:"மடக்கு வாக்கியம்",catMath:"கணிதம்",catText:"உரை",catLists:"பட்டியல்",catColour:"வண்ணம்",catVariables:"மாறிகள்",catFunctions:"சார்புகள்",listVariable:"பட்டியல் மாறி",textVariable:"உரை சரம்",httpRequestError:"இந்த செயலை இயக்குவதில் கோளாறு ஏற்பட்டது",linkAlert:"இந்த சுட்டி வழியாக நிரல் துண்டுகளை பகிரவும்:\n\n%1",hashError:"'%1' : இது சேமித்த நிரலாக தெரியவில்லை.",xmlError:"உங்களது நிரலை காணவில்லை; வேறு Blockly அத்தியாயத்தில் சேமித்தீரா?",badXml:"XML பகுப்பதில் கோளாறு:\n%1\n\nOK' கிளிக் செய்தால் மாற்றங்கள் இழப்பீர்கள்; பிழைகளுடன் தொடர 'Cancel' கிளிக் செய்யவும்."}}}}]);
//# sourceMappingURL=36.js.map