(window.webpackJsonp=window.webpackJsonp||[]).push([[26],{254:function(a,t){a.exports=function(){return{title:"Còde",blocks:"Blòts",linkTooltip:"Salva e liga als blòts.",runTooltip:"Aviar lo programa definit pels blòts dins l’espaci de trabalh.",badCode:"Error del programa :\n%1",timeout:"Nombre maximum d’iteracions d’execucion depassat.",trashTooltip:"Getar totes los blòts.",catLogic:"Logic",catLoops:"Boclas",catMath:"Math",catText:"Tèxte",catLists:"Listas",catColour:"Color",catVariables:"Variablas",catFunctions:"Foncions",listVariable:"lista",textVariable:"tèxte",httpRequestError:"I a agut un problèma amb la demanda.",linkAlert:"Partejatz vòstres blòts gràcia a aqueste ligam :\n\n%1",hashError:"O planhèm, '%1' correspond pas a un fichièr Blockly salvament.",xmlError:"Impossible de cargar lo fichièr de salvament.  Benlèu qu'es estat creat amb una autra version de Blockly ?",badXml:"Error d’analisi del XML :\n%1\n\nSeleccionar 'D'acòrdi' per abandonar vòstras modificacions o 'Anullar' per modificar encara lo XML."}}}}]);
//# sourceMappingURL=26.js.map