(window.webpackJsonp=window.webpackJsonp||[]).push([[4],{232:function(o,a){o.exports=function(){return{title:"Kód",blocks:"Bloky",linkTooltip:"Ulož a spoj bloky..",runTooltip:"",badCode:"Chyba programu:\n%1",timeout:"Maximum execution iterations exceeded.",trashTooltip:"Zahodit všechny bloky.",catLogic:"Logika",catLoops:"Smyčky",catMath:"Matematika",catText:"Text",catLists:"Seznamy",catColour:"Barva",catVariables:"Proměnné",catFunctions:"Procedury",listVariable:"seznam",textVariable:"text",httpRequestError:"Došlo k potížím s požadavkem.",linkAlert:"Sdílej bloky tímto odkazem: \n\n%1",hashError:"Omlouváme se, '%1' nesouhlasí s žádným z uložených souborů.",xmlError:"Nepodařilo se uložit vás soubor.  Pravděpodobně byl vytvořen jinou verzí Blockly?",badXml:"Chyba parsování XML:\n%1\n\nVybrat \"OK\" pro zahození vašich změn nebo 'Cancel' k dalšímu upravování XML."}}}}]);
//# sourceMappingURL=4.js.map