(window.webpackJsonp=window.webpackJsonp||[]).push([[17],{245:function(i,t){i.exports=function(){return{title:"Kóði",blocks:"Kubbar",linkTooltip:"Vista og tengja við kubba.",runTooltip:"Keyra forritið sem kubbarnir á vinnusvæðinu mynda.",badCode:"Villa í forriti:\n%1",timeout:"Forritið hefur endurtekið sig of oft.",trashTooltip:"Fleygja öllum kubbum.",catLogic:"Rökvísi",catLoops:"Lykkjur",catMath:"Reikningur",catText:"Texti",catLists:"Listar",catColour:"Litir",catVariables:"Breytur",catFunctions:"Stefjur",listVariable:"listi",textVariable:"texti",httpRequestError:"Það kom upp vandamál með beiðnina.",linkAlert:"Deildu kubbunum þínum með þessari krækju:",hashError:"Því miður, '%1' passar ekki við neitt vistað forrit.",xmlError:"Gat ekki hlaðið vistuðu skrána þína. Var hún kannske búin til í annarri útgáfu af Blockly?",badXml:"Villa við úrvinnslu XML:\n%1\n\nVeldu 'Í lagi' til að sleppa breytingum eða 'Hætta við' til að halda áfram með XML."}}}}]);
//# sourceMappingURL=17.js.map