(window.webpackJsonp=window.webpackJsonp||[]).push([[28],{256:function(a,i){a.exports=function(){return{title:"Còdes",blocks:"Blòch",linkTooltip:"Argistré e lijé ai blòch.",runTooltip:"Fé andé ël programa definì dai blòch ant lë spassi ëd travaj.",badCode:"Eror dël programa:\n%1",timeout:"Nùmer màssim d'arpetission d'esecussion sorpassà.",trashTooltip:"Scarté tuti ij blòch.",catLogic:"Lògica",catLoops:"Liasse",catMath:"Matemàtica",catText:"Test",catLists:"Liste",catColour:"Color",catVariables:"Variàbij",catFunctions:"Fonsion",listVariable:"lista",textVariable:"test",httpRequestError:"A-i é staje un problema con l'arcesta.",linkAlert:"Ch'a partagia ij sò blòch grassie a sta liura: %1",hashError:"An dëspias, '%1 a corëspond a gnun programa salvà.",xmlError:"A l'é nen podusse carié so archivi salvà. Miraco a l'é stàit creà con na version diferenta ëd Blockly?",badXml:"Eror d'anàlisi dl'XML:\n%1\n\nSelessioné 'Va bin' për lassé perde toe modìfiche o 'Anulé' për modifiché ancora l'XML."}}}}]);
//# sourceMappingURL=28.js.map