(window.webpackJsonp=window.webpackJsonp||[]).push([[14],{242:function(e,r){e.exports=function(){return{title:"Code",blocks:"Bausten",linkTooltip:"Speichre und auf Bausten verlinke.",runTooltip:"Das Programm ausfüahre, das von den Bausten im Oorweitsbereich definiert ist.",badCode:"Programmfehler:\n%1",timeout:"Die maximale Ausführungswiederholunge woore üwerschritt.",trashTooltip:"All Bausten verwerfe.",catLogic:"Logik",catLoops:"Schleife",catMath:"Mathematik",catText:"Text",catLists:"Liste",catColour:"Farreb",catVariables:"Variable",catFunctions:"Funktione",listVariable:"List",textVariable:"Text",httpRequestError:"Mit der Oonfroch hots en Problem geb.",linkAlert:"Tel von dein Bausten mit dem Link:\n\n%1",hashError:"„%1“ stimmt leider mit kenem üweren gespeicherte Programm.",xmlError:"Dein gespeicherte Datei könnt net gelood sin. Vielleicht woard se mit ener annre Version von Blockly erstellt.",badXml:"Fehler beim Parse von XML:\n%1\n\nWähle 'OK' zum Verwerfe von deiner Ändrunge orrer 'Abbreche' zum XML weiter beoorbeite."}}}}]);
//# sourceMappingURL=14.js.map