(window.webpackJsonp=window.webpackJsonp||[]).push([[32],{260:function(i,a){i.exports=function(){return{title:"Còdixi",blocks:"Brocus",linkTooltip:"Sarva e alliòngia a is brocus.",runTooltip:"Arròllia su programa cumpostu de is brocus in s'àrea de traballu.",badCode:"Errori in su Programa:\n%1",timeout:"Giai lòmpius a su màssimu numeru de repicus.",trashTooltip:"Boganci totu is brocus.",catLogic:"Lògica",catLoops:"Lòrigas",catMath:"Matemàtica",catText:"Testu",catLists:"Lista",catColour:"Colori",catVariables:"Variabilis",catFunctions:"Funtzionis",listVariable:"lista",textVariable:"testu",httpRequestError:"Ddui fut unu problema cun sa pregunta",linkAlert:"Poni is brocus tuus in custu acàpiu:\n\n%1",hashError:"Mi dispraxit, '%1' non torrat a pari cun nimancu unu de is programas sarvaus.",xmlError:"Non potzu carrigai su file sarvau. Fortzis est stètiu fatu cun d-una versioni diferenti de Blockly?",badXml:"Errori in s'anàlisi XML:\n%1\n\nCraca 'OK' po perdi is mudàntzias 'Anudda' po sighì a scriri su XML."}}}}]);
//# sourceMappingURL=32.js.map