(window.webpackJsonp=window.webpackJsonp||[]).push([[3],{231:function(e,a){e.exports=function(){return{title:"Codi",blocks:"Blocs",linkTooltip:"Desa i enllaça als blocs.",runTooltip:"Executa el programa definit pels blocs de l'àrea de treball.",badCode:"Error de programa:\n %1",timeout:"S'ha superat el nombre màxim d'iteracions d'execució.",trashTooltip:"Descarta tots els blocs.",catLogic:"Lògica",catLoops:"Bucles",catMath:"Matemàtiques",catText:"Text",catLists:"Llistes",catColour:"Color",catVariables:"Variables",catFunctions:"Procediments",listVariable:"llista",textVariable:"text",httpRequestError:"Hi ha hagut un problema amb la sol·licitud.",linkAlert:"Comparteix els teus blocs amb aquest enllaç: %1",hashError:"Ho sentim, '%1' no es correspon amb cap fitxer desat de Blockly.",xmlError:"No s'ha pogut carregar el teu fitxer desat.  Potser va ser creat amb una versió diferent de Blockly?",badXml:"Error d'anàlisi XML:\n%1\n\nSeleccioneu 'Acceptar' per abandonar els vostres canvis, o 'Cancel·lar' per continuar editant l'XML."}}}}]);
//# sourceMappingURL=3.js.map