(window.webpackJsonp=window.webpackJsonp||[]).push([[20],{248:function(a,e){a.exports=function(){return{title:"Tangalt",blocks:"Iḥedran",linkTooltip:"Sekles sakin cudd ar iḥedran.",runTooltip:"Senker ahil i d-sbadun iḥedran di tallunt n umahil.",badCode:"Tuccḍa deg ahil :\n%1",timeout:"Amḍan afellay n wallusen n uselkem iɛeddan.",trashTooltip:"Ḍeggeṛ akk iḥedran.",catLogic:"Tameẓla",catLoops:"Tineddicin",catMath:"Tusnakt",catText:"Aḍris",catLists:"Tibdarin",catColour:"Ini",catVariables:"Imuttiyen",catFunctions:"Tiwiriwin",listVariable:"tabdart",textVariable:"aḍris",httpRequestError:"yella ugur deg usuter.",linkAlert:"Bḍu iḥedran-ik s useqdec n useɣwen-agi:\n\n%1",hashError:"Suref-aɣ, '%1' ur imenṭaḍ ulad d yiwen n wahil yettwaskelsen.",xmlError:"Ur izmir ara ad d-isali afaylu  n usekles. Ahatyettwarna s lqem-nniḍen n Blockly?",badXml:"Tuccḍa di tesleḍt n XML :\n%1\n\nFren 'IH' akken ad tzgleḍ asnifel-ik 'Sefsex' akken ad tkemmleḍ asnifel n XML."}}}}]);
//# sourceMappingURL=20.js.map