(window.webpackJsonp=window.webpackJsonp||[]).push([[33],{261:function(o,a){o.exports=function(){return{title:"Kód",blocks:"Bloky",linkTooltip:"Uložiť a zdieľať odkaz na tento program.",runTooltip:"Spustiť program, zložený z dielcov na pracovnej ploche.",badCode:"Chyba v programe:\n%1",timeout:"Bol prekročený maximálny počet opakovaní.",trashTooltip:"Zahodiť všetky dielce.",catLogic:"Logika",catLoops:"Cykly",catMath:"Matematické",catText:"Text",catLists:"Zoznamy",catColour:"Farby",catVariables:"Premenné",catFunctions:"Funkcie",listVariable:"zoznam",textVariable:"text",httpRequestError:"Problém so spracovaním požiadavky.",linkAlert:"Zdieľať tento program skopírovaním odkazu\n\n%1",hashError:"Prepáč, '%1' nie je meno žiadnemu uloženému programu.",xmlError:"Nebolo možné načítať uložený súbor. Možno bol vytvorený v inej verzii Blocky.",badXml:"Chyba pri parsovaní XML:\n%1\n\nStlačte 'OK' ak chcete zrušiť zmeny alebo 'Zrušiť' pre pokračovanie v úpravách XML."}}}}]);
//# sourceMappingURL=33.js.map