(window.webpackJsonp=window.webpackJsonp||[]).push([[31],{259:function(t,o){t.exports=function(){return{title:"Код",blocks:"Блоки",linkTooltip:"Сохранить и показать ссылку на блоки.",runTooltip:"Запустить программу, заданную блоками в рабочей области.",badCode:"Ошибка программы:\n%1",timeout:"Превышено максимальное количество итераций.",trashTooltip:"Удалить все блоки.",catLogic:"Логические",catLoops:"Циклы",catMath:"Математика",catText:"Текст",catLists:"Списки",catColour:"Цвет",catVariables:"Переменные",catFunctions:"Функции",listVariable:"список",textVariable:"текст",httpRequestError:"Произошла проблема при запросе.",linkAlert:"Поделитесь своими блоками по этой ссылке:\n\n%1",hashError:"К сожалению, «%1» не соответствует ни одному сохраненному файлу Блокли.",xmlError:"Не удалось загрузить ваш сохраненный файл.  Возможно, он был создан в другой версии Блокли?",badXml:"Ошибка синтаксического анализа XML:\n%1\n\nВыберите 'ОК', чтобы отказаться от изменений или 'Cancel' для дальнейшего редактирования XML."}}}}]);
//# sourceMappingURL=31.js.map