(window.webpackJsonp=window.webpackJsonp||[]).push([[12],{240:function(e,r){e.exports=function(){return{title:"Code",blocks:"Blocs",linkTooltip:"Sauvegarder et lier aux blocs.",runTooltip:"Lancer le programme défini par les blocs dans l’espace de travail.",badCode:"Erreur du programme :\n%1",timeout:"Nombre maximum d’itérations d’exécution dépassé.",trashTooltip:"Jeter tous les blocs.",catLogic:"Logique",catLoops:"Boucles",catMath:"Math",catText:"Texte",catLists:"Listes",catColour:"Couleur",catVariables:"Variables",catFunctions:"Fonctions",listVariable:"liste",textVariable:"texte",httpRequestError:"Il y a eu un problème avec la demande.",linkAlert:"Partagez vos blocs grâce à ce lien:\n\n%1",hashError:"Désolé, '%1' ne correspond à aucun programme sauvegardé.",xmlError:"Impossible de charger le fichier de sauvegarde.  Peut être a t-il été créé avec une autre version de Blockly?",badXml:"Erreur d’analyse du XML :\n%1\n\nSélectionner 'OK' pour abandonner vos modifications ou 'Annuler' pour continuer à modifier le XML."}}}}]);
//# sourceMappingURL=12.js.map