(window.webpackJsonp=window.webpackJsonp||[]).push([[2],{230:function(a,e){a.exports=function(){return{title:"Kod",blocks:"Bloc'hoù",linkTooltip:"Enrollañ ha liammañ d'ar bloc'hadoù.",runTooltip:"Lañsañ ar programm termenet gant ar bloc'hadoù en takad labour.",badCode:"Fazi programm :\n%1",timeout:"Tizhet eo bet an niver brasañ a iteradurioù seveniñ aotreet.",trashTooltip:"Disteurel an holl vloc'hoù.",catLogic:"Poell",catLoops:"Boukloù",catMath:"Matematik",catText:"Testenn",catLists:"Rolloù",catColour:"Liv",catVariables:"Argemmennoù",catFunctions:"Arc'hwelioù",listVariable:"roll",textVariable:"testenn",httpRequestError:"Ur gudenn zo gant ar reked.",linkAlert:"Rannañ ho ploc'hoù gant al liamm-mañ :\n\n%1",hashError:'Digarezit. "%1" ne glot gant programm enrollet ebet.',xmlError:"Ne c'haller ket kargañ ho restr enrollet. Marteze e oa bet krouet gant ur stumm disheñvel eus Blockly ?",badXml:'Fazi dielfennañ XML :\n%1\n\nDibabit "Mat eo" evit dilezel ar c\'hemmoù-se pe "Nullañ" evit kemmañ an XML c\'hoazh.'}}}}]);
//# sourceMappingURL=2.js.map