(window.webpackJsonp=window.webpackJsonp||[]).push([[22],{250:function(t,o){t.exports=function(){return{title:"Код",blocks:"Блокчиња",linkTooltip:"Зачувај и стави врска до блокчињата.",runTooltip:"Пушти го програмот определен од блокчињата во работниот простор.",badCode:"Грешка во програмот:\n%1",timeout:"Го надминавте допуштениот број на повторувања во извршувањето.",trashTooltip:"Отстрани ги сите блокчиња.",catLogic:"Логика",catLoops:"Јамки",catMath:"Математика",catText:"Текст",catLists:"Списоци",catColour:"Боја",catVariables:"Променливи",catFunctions:"Функции",listVariable:"список",textVariable:"текст",httpRequestError:"Се појави проблем во барањето.",linkAlert:"Споделете ги вашите блокчиња со оваа врска:\n\n%1",hashError:"„%1“ не одговара на ниеден зачуван програм.",xmlError:"Не можев да ја вчитам зачуваната податотека. Да не сте ја создале со друга верзија на Blockly?",badXml:"Грешка при расчленувањето на XML:\n%1\n\nСтиснете на „ОК“ за да ги напуштите промените или на „Откажи“ ако сакате уште да ја уредувате XML-податотеката."}}}}]);
//# sourceMappingURL=22.js.map