(window.webpackJsonp=window.webpackJsonp||[]).push([[18],{246:function(o,i){o.exports=function(){return{title:"Codice",blocks:"Blocchi",linkTooltip:"Salva e collega ai blocchi.",runTooltip:"Esegui il programma definito dai blocchi nell'area di lavoro.",badCode:"Errore programma:\n%1",timeout:"È stato superato il numero massimo consentito di interazioni eseguite.",trashTooltip:"Elimina tutti i blocchi.",catLogic:"Logica",catLoops:"Cicli",catMath:"Matematica",catText:"Testo",catLists:"Elenchi",catColour:"Colore",catVariables:"Variabili",catFunctions:"Funzioni",listVariable:"elenco",textVariable:"testo",httpRequestError:"La richiesta non è stata soddisfatta.",linkAlert:"Condividi i tuoi blocchi con questo collegamento:\n\n%1",hashError:"Mi spiace, '%1' non corrisponde ad alcun programma salvato.",xmlError:"Non è stato possibile caricare il documento.  Forse è stato creato con una versione diversa di Blockly?",badXml:"Errore durante l'analisi XML:\n%1\n\nSeleziona 'OK' per abbandonare le modifiche o 'Annulla' per continuare a modificare l'XML."}}}}]);
//# sourceMappingURL=18.js.map