(window.webpackJsonp=window.webpackJsonp||[]).push([[5],{233:function(e,r){e.exports=function(){return{title:"Kode",blocks:"Blokke",linkTooltip:"Gem og link til blokke.",runTooltip:"Kør programmet, der er defineret af blokkene i arbejdsområdet.",badCode:"Programfejl:\n%1",timeout:"Maksimale antal udførelsesgentagelser overskredet.",trashTooltip:"Kassér alle blokke.",catLogic:"Logik",catLoops:"Løkker",catMath:"Matematik",catText:"Tekst",catLists:"Lister",catColour:"Farve",catVariables:"Variabler",catFunctions:"Funktioner",listVariable:"liste",textVariable:"tekst",httpRequestError:"Der var et problem med forespørgslen.",linkAlert:"Del dine blokke med dette link:\n\n%1",hashError:"Beklager, '%1' passer ikke med nogen gemt Blockly fil.",xmlError:"Kunne ikke hente din gemte fil.  Måske er den lavet med en anden udgave af Blockly?",badXml:"Fejl under fortolkningen af XML:\n%1\n\nVælg 'OK' for at opgive dine ændringer eller 'Afbryd' for at redigere XML-filen yderligere."}}}}]);
//# sourceMappingURL=5.js.map