(window.webpackJsonp=window.webpackJsonp||[]).push([[6],{234:function(e,n){e.exports=function(){return{title:"Code",blocks:"Bausteine",linkTooltip:"Speichern und auf Bausteine verlinken.",runTooltip:"Das Programm ausführen, das von den Bausteinen im Arbeitsbereich definiert ist.",badCode:"Programmfehler:\n%1",timeout:"Die maximalen Ausführungswiederholungen wurden überschritten.",trashTooltip:"Alle Bausteine verwerfen.",catLogic:"Logik",catLoops:"Schleifen",catMath:"Mathematik",catText:"Text",catLists:"Listen",catColour:"Farbe",catVariables:"Variablen",catFunctions:"Funktionen",listVariable:"Liste",textVariable:"Text",httpRequestError:"Mit der Anfrage gab es ein Problem.",linkAlert:"Teile deine Bausteine mit diesem Link:\n\n%1",hashError:"„%1“ stimmt leider mit keinem gespeicherten Programm überein.",xmlError:"Deine gespeicherte Datei konnte nicht geladen werden. Vielleicht wurde sie mit einer anderen Version von Blockly erstellt.",badXml:"Fehler beim Parsen von XML:\n%1\n\nWähle 'OK' zum Verwerfen deiner Änderungen oder 'Abbrechen' zum weiteren Bearbeiten des XML."}}}}]);
//# sourceMappingURL=6.js.map