(window.webpackJsonp=window.webpackJsonp||[]).push([[41],{269:function(n,t){n.exports=function(){return{title:"Chương trình",blocks:"Các mảnh",linkTooltip:"Lưu và lấy địa chỉ liên kết.",runTooltip:"Chạy chương trình.",badCode:"'Lỗi chương trình:\n%1",timeout:"Đã vượt quá số lần lặp cho phép.",trashTooltip:"Xóa tất cả mọi mảnh.",catLogic:"Logic",catLoops:"Vòng lặp",catMath:"Công thức toán",catText:"Văn bản",catLists:"Danh sách",catColour:"Màu",catVariables:"Biến",catFunctions:"Hàm",listVariable:"danh sách",textVariable:"văn bản",httpRequestError:"Hoạt động bị trục trặc, không thực hiện được yêu cầu của bạn.",linkAlert:"Chia sẻ chương trình của bạn với liên kết sau:\n\n %1",hashError:"Không tìm thấy chương trình được lưu ở '%1'.",xmlError:"Không mở được chương trình của bạn.  Có thể nó nằm trong một phiên bản khác của Blockly?",badXml:"Lỗi sử lý XML:\n %1\n\nChọn 'OK' để từ bỏ các thay đổi hoặc 'Hủy' để tiếp tục chỉnh sửa các XML."}}}}]);
//# sourceMappingURL=41.js.map