(window.webpackJsonp=window.webpackJsonp||[]).push([[15],{243:function(t,a){t.exports=function(){return{title:"Kódszerkesztő",blocks:"Blokkok",linkTooltip:"Hivatkozás létrehozása",runTooltip:"Program futtatása.",badCode:"Program hiba:\n%1",timeout:"A program elérte a maximális végrehajtási időt.",trashTooltip:"Összes blokk törlése.",catLogic:"Logikai műveletek",catLoops:"Ciklusok",catMath:"Matematikai műveletek",catText:"Sztring műveletek",catLists:"Listakezelés",catColour:"Színek",catVariables:"Változók",catFunctions:"Eljárások",listVariable:"lista",textVariable:"szöveg",httpRequestError:"A kéréssel kapcsolatban probléma merült fel.",linkAlert:"Ezzel a hivatkozással tudod megosztani a programodat:\n\n%1",hashError:"Sajnos a '%1' hivatkozás nem tartozik egyetlen programhoz sem.",xmlError:"A programodat nem lehet betölteni.  Elképzelhető, hogy a Blockly egy másik verziójában készült?",badXml:"Hiba az XML feldolgozásakor:\n%1\n\nVáltozások elvetése?"}}}}]);
//# sourceMappingURL=15.js.map